Class: Svix::ApplicationIn
- Inherits:
-
Object
- Object
- Svix::ApplicationIn
- Defined in:
- lib/svix/models/application_in.rb
Instance Attribute Summary collapse
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Application name for human consumption.
-
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
-
#uid ⇒ Object
Optional unique identifier for the application.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ApplicationIn
constructor
A new instance of ApplicationIn.
- #serialize ⇒ Object
-
#to_json ⇒ Object
Serializes the object to a json string.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationIn
Returns a new instance of ApplicationIn.
20 21 22 23 24 25 26 27 28 29 30 31 32 33 |
# File 'lib/svix/models/application_in.rb', line 20 def initialize(attributes = {}) unless attributes.is_a?(Hash) fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::ApplicationIn` new method") end attributes.each do |k, v| unless ALL_FIELD.include?(k.to_s) fail(ArgumentError, "The field #{k} is not part of Svix::ApplicationIn") end instance_variable_set("@#{k}", v) instance_variable_set("@__#{k}_is_defined", true) end end |
Instance Attribute Details
#metadata ⇒ Object
Returns the value of attribute metadata.
15 16 17 |
# File 'lib/svix/models/application_in.rb', line 15 def @metadata end |
#name ⇒ Object
Application name for human consumption.
8 9 10 |
# File 'lib/svix/models/application_in.rb', line 8 def name @name end |
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
Outgoing messages will be throttled to this rate.
12 13 14 |
# File 'lib/svix/models/application_in.rb', line 12 def throttle_rate @throttle_rate end |
#uid ⇒ Object
Optional unique identifier for the application.
14 15 16 |
# File 'lib/svix/models/application_in.rb', line 14 def uid @uid end |
Class Method Details
.deserialize(attributes = {}) ⇒ Object
35 36 37 38 39 40 41 42 43 |
# File 'lib/svix/models/application_in.rb', line 35 def self.deserialize(attributes = {}) attributes = attributes.transform_keys(&:to_s) attrs = Hash.new attrs["name"] = attributes["name"] attrs["throttle_rate"] = attributes["throttleRate"] attrs["uid"] = attributes["uid"] attrs["metadata"] = attributes["metadata"] new(attrs) end |
Instance Method Details
#serialize ⇒ Object
45 46 47 48 49 50 51 52 |
# File 'lib/svix/models/application_in.rb', line 45 def serialize out = Hash.new out["name"] = Svix::serialize_primitive(@name) if @name out["throttleRate"] = Svix::serialize_primitive(@throttle_rate) if @throttle_rate out["uid"] = Svix::serialize_primitive(@uid) if @uid out["metadata"] = Svix::serialize_primitive(@metadata) if @metadata out end |
#to_json ⇒ Object
Serializes the object to a json string
56 57 58 |
# File 'lib/svix/models/application_in.rb', line 56 def to_json JSON.dump(serialize) end |