Class: Svix::ApplicationOut
- Inherits:
-
Object
- Object
- Svix::ApplicationOut
- Defined in:
- lib/svix/models/application_out.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
The Application’s ID.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Application name for human consumption.
-
#rate_limit ⇒ Object
Deprecated, use ‘throttleRate` instead.
-
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
-
#uid ⇒ Object
Optional unique identifier for the application.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ApplicationOut
constructor
A new instance of ApplicationOut.
- #serialize ⇒ Object
-
#to_json ⇒ Object
Serializes the object to a json string.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationOut
Returns a new instance of ApplicationOut.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/svix/models/application_out.rb', line 26 def initialize(attributes = {}) unless attributes.is_a?(Hash) fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::ApplicationOut` new method") end attributes.each do |k, v| unless ALL_FIELD.include?(k.to_s) fail(ArgumentError, "The field #{k} is not part of Svix::ApplicationOut") end instance_variable_set("@#{k}", v) instance_variable_set("@__#{k}_is_defined", true) end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
7 8 9 |
# File 'lib/svix/models/application_out.rb', line 7 def created_at @created_at end |
#id ⇒ Object
The Application’s ID.
9 10 11 |
# File 'lib/svix/models/application_out.rb', line 9 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
10 11 12 |
# File 'lib/svix/models/application_out.rb', line 10 def @metadata end |
#name ⇒ Object
Application name for human consumption.
12 13 14 |
# File 'lib/svix/models/application_out.rb', line 12 def name @name end |
#rate_limit ⇒ Object
Deprecated, use ‘throttleRate` instead.
14 15 16 |
# File 'lib/svix/models/application_out.rb', line 14 def rate_limit @rate_limit end |
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
Outgoing messages will be throttled to this rate.
18 19 20 |
# File 'lib/svix/models/application_out.rb', line 18 def throttle_rate @throttle_rate end |
#uid ⇒ Object
Optional unique identifier for the application.
20 21 22 |
# File 'lib/svix/models/application_out.rb', line 20 def uid @uid end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
21 22 23 |
# File 'lib/svix/models/application_out.rb', line 21 def updated_at @updated_at end |
Class Method Details
.deserialize(attributes = {}) ⇒ Object
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/svix/models/application_out.rb', line 41 def self.deserialize(attributes = {}) attributes = attributes.transform_keys(&:to_s) attrs = Hash.new attrs["created_at"] = DateTime.rfc3339(attributes["createdAt"]).to_time attrs["id"] = attributes["id"] attrs["metadata"] = attributes["metadata"] attrs["name"] = attributes["name"] attrs["rate_limit"] = attributes["rateLimit"] attrs["throttle_rate"] = attributes["throttleRate"] attrs["uid"] = attributes["uid"] attrs["updated_at"] = DateTime.rfc3339(attributes["updatedAt"]).to_time new(attrs) end |
Instance Method Details
#serialize ⇒ Object
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/svix/models/application_out.rb', line 55 def serialize out = Hash.new out["createdAt"] = Svix::serialize_primitive(@created_at) if @created_at out["id"] = Svix::serialize_primitive(@id) if @id out["metadata"] = Svix::serialize_primitive(@metadata) if @metadata out["name"] = Svix::serialize_primitive(@name) if @name out["rateLimit"] = Svix::serialize_primitive(@rate_limit) if @rate_limit out["throttleRate"] = Svix::serialize_primitive(@throttle_rate) if @throttle_rate out["uid"] = Svix::serialize_primitive(@uid) if @uid out["updatedAt"] = Svix::serialize_primitive(@updated_at) if @updated_at out end |
#to_json ⇒ Object
Serializes the object to a json string
70 71 72 |
# File 'lib/svix/models/application_out.rb', line 70 def to_json JSON.dump(serialize) end |