Class: Svix::ApplicationPatch
- Inherits:
-
Object
- Object
- Svix::ApplicationPatch
- Defined in:
- lib/svix/models/application_patch.rb
Instance Attribute Summary collapse
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
-
#uid ⇒ Object
The Application's UID.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ApplicationPatch
constructor
A new instance of ApplicationPatch.
- #serialize ⇒ Object
-
#to_json ⇒ Object
Serializes the object to a json string.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationPatch
Returns a new instance of ApplicationPatch.
19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/svix/models/application_patch.rb', line 19 def initialize(attributes = {}) unless attributes.is_a?(Hash) fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::ApplicationPatch` new method") end attributes.each do |k, v| unless ALL_FIELD.include?(k.to_s) fail(ArgumentError, "The field #{k} is not part of Svix::ApplicationPatch") end instance_variable_set("@#{k}", v) instance_variable_set("@__#{k}_is_defined", true) end end |
Instance Attribute Details
#metadata ⇒ Object
Returns the value of attribute metadata.
14 15 16 |
# File 'lib/svix/models/application_patch.rb', line 14 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
7 8 9 |
# File 'lib/svix/models/application_patch.rb', line 7 def name @name end |
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
Outgoing messages will be throttled to this rate.
11 12 13 |
# File 'lib/svix/models/application_patch.rb', line 11 def throttle_rate @throttle_rate end |
#uid ⇒ Object
The Application's UID.
13 14 15 |
# File 'lib/svix/models/application_patch.rb', line 13 def uid @uid end |
Class Method Details
.deserialize(attributes = {}) ⇒ Object
34 35 36 37 38 39 40 41 42 |
# File 'lib/svix/models/application_patch.rb', line 34 def self.deserialize(attributes = {}) attributes = attributes.transform_keys(&:to_s) attrs = Hash.new attrs["name"] = attributes["name"] attrs["throttle_rate"] = attributes["throttleRate"] attrs["uid"] = attributes["uid"] attrs["metadata"] = attributes["metadata"] new(attrs) end |
Instance Method Details
#serialize ⇒ Object
44 45 46 47 48 49 50 51 |
# File 'lib/svix/models/application_patch.rb', line 44 def serialize out = Hash.new out["name"] = Svix::serialize_primitive(@name) if @name out["throttleRate"] = Svix::serialize_primitive(@throttle_rate) if @__throttle_rate_is_defined out["uid"] = Svix::serialize_primitive(@uid) if @__uid_is_defined out["metadata"] = Svix::serialize_primitive(@metadata) if @metadata out end |
#to_json ⇒ Object
Serializes the object to a json string
55 56 57 |
# File 'lib/svix/models/application_patch.rb', line 55 def to_json JSON.dump(serialize) end |