Class: Svix::EndpointSecretRotateIn

Inherits:
Object
  • Object
show all
Defined in:
lib/svix/models/endpoint_secret_rotate_in.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EndpointSecretRotateIn

Returns a new instance of EndpointSecretRotateIn.



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/svix/models/endpoint_secret_rotate_in.rb', line 20

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    fail(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Svix::EndpointSecretRotateIn` new method"
    )
  end

  attributes.each do |k, v|
    unless ALL_FIELD.include?(k.to_s)
      fail(ArgumentError, "The field #{k} is not part of Svix::EndpointSecretRotateIn")
    end

    instance_variable_set("@#{k}", v)
    instance_variable_set("@__#{k}_is_defined", true)
  end
end

Instance Attribute Details

#grace_period_secondsObject

How long the old secret will be valid for, in seconds.

Valid values are between 0 (immediate expiry) and 7 days. The default is 24 hours.



10
11
12
# File 'lib/svix/models/endpoint_secret_rotate_in.rb', line 10

def grace_period_seconds
  @grace_period_seconds
end

#keyObject

The endpoint's verification secret.

Format: base64 encoded random bytes optionally prefixed with whsec_. It is recommended to not set this and let the server generate the secret.



15
16
17
# File 'lib/svix/models/endpoint_secret_rotate_in.rb', line 15

def key
  @key
end

Class Method Details

.deserialize(attributes = {}) ⇒ Object



38
39
40
41
42
43
44
# File 'lib/svix/models/endpoint_secret_rotate_in.rb', line 38

def self.deserialize(attributes = {})
  attributes = attributes.transform_keys(&:to_s)
  attrs = Hash.new
  attrs["grace_period_seconds"] = attributes["gracePeriodSeconds"]
  attrs["key"] = attributes["key"]
  new(attrs)
end

Instance Method Details

#serializeObject



46
47
48
49
50
51
# File 'lib/svix/models/endpoint_secret_rotate_in.rb', line 46

def serialize
  out = Hash.new
  out["gracePeriodSeconds"] = Svix::serialize_primitive(@grace_period_seconds) if @grace_period_seconds
  out["key"] = Svix::serialize_primitive(@key) if @key
  out
end

#to_jsonObject

Serializes the object to a json string

Returns:

  • String



55
56
57
# File 'lib/svix/models/endpoint_secret_rotate_in.rb', line 55

def to_json
  JSON.dump(serialize)
end