Class: Svix::EndpointUpdate

Inherits:
Object
  • Object
show all
Defined in:
lib/svix/models/endpoint_update.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EndpointUpdate

Returns a new instance of EndpointUpdate.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/svix/models/endpoint_update.rb', line 38

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::EndpointUpdate` new method")
  end

  attributes.each do |k, v|
    unless ALL_FIELD.include?(k.to_s)
      fail(ArgumentError, "The field #{k} is not part of Svix::EndpointUpdate")
    end

    instance_variable_set("@#{k}", v)
    instance_variable_set("@__#{k}_is_defined", true)
  end
end

Instance Attribute Details

#channelsObject

List of message channels this endpoint listens to (omit for all).



8
9
10
# File 'lib/svix/models/endpoint_update.rb', line 8

def channels
  @channels
end

#descriptionObject

Returns the value of attribute description.



9
10
11
# File 'lib/svix/models/endpoint_update.rb', line 9

def description
  @description
end

#disabledObject

Returns the value of attribute disabled.



10
11
12
# File 'lib/svix/models/endpoint_update.rb', line 10

def disabled
  @disabled
end

#filter_typesObject

Returns the value of attribute filter_types.



11
12
13
# File 'lib/svix/models/endpoint_update.rb', line 11

def filter_types
  @filter_types
end

#metadataObject

Returns the value of attribute metadata.



12
13
14
# File 'lib/svix/models/endpoint_update.rb', line 12

def 
  @metadata
end

#rate_limitObject

Deprecated, use ‘throttleRate` instead.



14
15
16
# File 'lib/svix/models/endpoint_update.rb', line 14

def rate_limit
  @rate_limit
end

#throttle_rateObject

Maximum messages per second to send to this endpoint.

Outgoing messages will be throttled to this rate.



18
19
20
# File 'lib/svix/models/endpoint_update.rb', line 18

def throttle_rate
  @throttle_rate
end

#uidObject

Optional unique identifier for the endpoint.



20
21
22
# File 'lib/svix/models/endpoint_update.rb', line 20

def uid
  @uid
end

#urlObject

Returns the value of attribute url.



21
22
23
# File 'lib/svix/models/endpoint_update.rb', line 21

def url
  @url
end

#versionObject

Returns the value of attribute version.



22
23
24
# File 'lib/svix/models/endpoint_update.rb', line 22

def version
  @version
end

Class Method Details

.deserialize(attributes = {}) ⇒ Object



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/svix/models/endpoint_update.rb', line 53

def self.deserialize(attributes = {})
  attributes = attributes.transform_keys(&:to_s)
  attrs = Hash.new
  attrs["channels"] = attributes["channels"]
  attrs["description"] = attributes["description"]
  attrs["disabled"] = attributes["disabled"]
  attrs["filter_types"] = attributes["filterTypes"]
  attrs["metadata"] = attributes["metadata"]
  attrs["rate_limit"] = attributes["rateLimit"]
  attrs["throttle_rate"] = attributes["throttleRate"]
  attrs["uid"] = attributes["uid"]
  attrs["url"] = attributes["url"]
  attrs["version"] = attributes["version"]
  new(attrs)
end

Instance Method Details

#serializeObject



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/svix/models/endpoint_update.rb', line 69

def serialize
  out = Hash.new
  out["channels"] = Svix::serialize_primitive(@channels) if @channels
  out["description"] = Svix::serialize_primitive(@description) if @description
  out["disabled"] = Svix::serialize_primitive(@disabled) if @disabled
  out["filterTypes"] = Svix::serialize_primitive(@filter_types) if @filter_types
  out["metadata"] = Svix::serialize_primitive(@metadata) if @metadata
  out["rateLimit"] = Svix::serialize_primitive(@rate_limit) if @rate_limit
  out["throttleRate"] = Svix::serialize_primitive(@throttle_rate) if @throttle_rate
  out["uid"] = Svix::serialize_primitive(@uid) if @uid
  out["url"] = Svix::serialize_primitive(@url) if @url
  out["version"] = Svix::serialize_primitive(@version) if @version
  out
end

#to_jsonObject

Serializes the object to a json string

Returns:

  • String



86
87
88
# File 'lib/svix/models/endpoint_update.rb', line 86

def to_json
  JSON.dump(serialize)
end