Class: Svix::EventBridgeConfig
- Inherits:
-
Object
- Object
- Svix::EventBridgeConfig
- Defined in:
- lib/svix/models/event_bridge_config.rb
Direct Known Subclasses
StreamSinkInConfig::EventBridge, StreamSinkOutConfig::EventBridge
Instance Attribute Summary collapse
-
#access_key_id ⇒ Object
Returns the value of attribute access_key_id.
-
#detail_type ⇒ Object
Free-form string, with a maximum of 128 characters.
-
#event_bus_name ⇒ Object
The name or ARN of the event bus to receive the event.
-
#region ⇒ Object
Returns the value of attribute region.
-
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ EventBridgeConfig
constructor
A new instance of EventBridgeConfig.
- #serialize ⇒ Object
-
#to_json ⇒ Object
Serializes the object to a json string.
Constructor Details
#initialize(attributes = {}) ⇒ EventBridgeConfig
Returns a new instance of EventBridgeConfig.
18 19 20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'lib/svix/models/event_bridge_config.rb', line 18 def initialize(attributes = {}) unless attributes.is_a?(Hash) fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::EventBridgeConfig` new method") end attributes.each do |k, v| unless ALL_FIELD.include?(k.to_s) fail(ArgumentError, "The field #{k} is not part of Svix::EventBridgeConfig") end instance_variable_set("@#{k}", v) instance_variable_set("@__#{k}_is_defined", true) end end |
Instance Attribute Details
#access_key_id ⇒ Object
Returns the value of attribute access_key_id.
7 8 9 |
# File 'lib/svix/models/event_bridge_config.rb', line 7 def access_key_id @access_key_id end |
#detail_type ⇒ Object
Free-form string, with a maximum of 128 characters
9 10 11 |
# File 'lib/svix/models/event_bridge_config.rb', line 9 def detail_type @detail_type end |
#event_bus_name ⇒ Object
The name or ARN of the event bus to receive the event
11 12 13 |
# File 'lib/svix/models/event_bridge_config.rb', line 11 def event_bus_name @event_bus_name end |
#region ⇒ Object
Returns the value of attribute region.
12 13 14 |
# File 'lib/svix/models/event_bridge_config.rb', line 12 def region @region end |
#secret_access_key ⇒ Object
Returns the value of attribute secret_access_key.
13 14 15 |
# File 'lib/svix/models/event_bridge_config.rb', line 13 def secret_access_key @secret_access_key end |
Class Method Details
.deserialize(attributes = {}) ⇒ Object
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/svix/models/event_bridge_config.rb', line 33 def self.deserialize(attributes = {}) attributes = attributes.transform_keys(&:to_s) attrs = Hash.new attrs["access_key_id"] = attributes["accessKeyId"] attrs["detail_type"] = attributes["detailType"] attrs["event_bus_name"] = attributes["eventBusName"] attrs["region"] = attributes["region"] attrs["secret_access_key"] = attributes["secretAccessKey"] new(attrs) end |
Instance Method Details
#serialize ⇒ Object
44 45 46 47 48 49 50 51 52 |
# File 'lib/svix/models/event_bridge_config.rb', line 44 def serialize out = Hash.new out["accessKeyId"] = Svix::serialize_primitive(@access_key_id) if @access_key_id out["detailType"] = Svix::serialize_primitive(@detail_type) if @detail_type out["eventBusName"] = Svix::serialize_primitive(@event_bus_name) if @event_bus_name out["region"] = Svix::serialize_primitive(@region) if @region out["secretAccessKey"] = Svix::serialize_primitive(@secret_access_key) if @secret_access_key out end |
#to_json ⇒ Object
Serializes the object to a json string
56 57 58 |
# File 'lib/svix/models/event_bridge_config.rb', line 56 def to_json JSON.dump(serialize) end |