Class: Svix::EventBridgeConfigIn

Inherits:
Object
  • Object
show all
Defined in:
lib/svix/models/event_bridge_config_in.rb

Direct Known Subclasses

StreamSinkInConfig::EventBridge

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EventBridgeConfigIn

Returns a new instance of EventBridgeConfigIn.



27
28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/svix/models/event_bridge_config_in.rb', line 27

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::EventBridgeConfigIn` new method")
  end

  attributes.each do |k, v|
    unless ALL_FIELD.include?(k.to_s)
      fail(ArgumentError, "The field #{k} is not part of Svix::EventBridgeConfigIn")
    end

    instance_variable_set("@#{k}", v)
    instance_variable_set("@__#{k}_is_defined", true)
  end
end

Instance Attribute Details

#access_key_idObject

Access key ID.

Currently a required field, but marked as optional because we may add different authentication in the future.



14
15
16
# File 'lib/svix/models/event_bridge_config_in.rb', line 14

def access_key_id
  @access_key_id
end

#detail_typeObject

Free-form string, with a maximum of 128 characters



10
11
12
# File 'lib/svix/models/event_bridge_config_in.rb', line 10

def detail_type
  @detail_type
end

#event_bus_nameObject

The name or ARN of the event bus to receive the event



8
9
10
# File 'lib/svix/models/event_bridge_config_in.rb', line 8

def event_bus_name
  @event_bus_name
end

#regionObject

The region of the EventBridge bus.

Currently a required field, but marked as optional because we may infer it from other fields in the future.



22
23
24
# File 'lib/svix/models/event_bridge_config_in.rb', line 22

def region
  @region
end

#secret_access_keyObject

Secret access key.

Currently a required field, but marked as optional because we may add different authentication in the future.



18
19
20
# File 'lib/svix/models/event_bridge_config_in.rb', line 18

def secret_access_key
  @secret_access_key
end

Class Method Details

.deserialize(attributes = {}) ⇒ Object



42
43
44
45
46
47
48
49
50
51
# File 'lib/svix/models/event_bridge_config_in.rb', line 42

def self.deserialize(attributes = {})
  attributes = attributes.transform_keys(&:to_s)
  attrs = Hash.new
  attrs["event_bus_name"] = attributes["eventBusName"]
  attrs["detail_type"] = attributes["detailType"]
  attrs["access_key_id"] = attributes["accessKeyId"]
  attrs["secret_access_key"] = attributes["secretAccessKey"]
  attrs["region"] = attributes["region"]
  new(attrs)
end

Instance Method Details

#serializeObject



53
54
55
56
57
58
59
60
61
# File 'lib/svix/models/event_bridge_config_in.rb', line 53

def serialize
  out = Hash.new
  out["eventBusName"] = Svix::serialize_primitive(@event_bus_name) if @event_bus_name
  out["detailType"] = Svix::serialize_primitive(@detail_type) if @detail_type
  out["accessKeyId"] = Svix::serialize_primitive(@access_key_id) if @access_key_id
  out["secretAccessKey"] = Svix::serialize_primitive(@secret_access_key) if @secret_access_key
  out["region"] = Svix::serialize_primitive(@region) if @region
  out
end

#to_jsonObject

Serializes the object to a json string

Returns:

  • String



65
66
67
# File 'lib/svix/models/event_bridge_config_in.rb', line 65

def to_json
  JSON.dump(serialize)
end