Class: Svix::IngestEndpointOut
- Inherits:
-
Object
- Object
- Svix::IngestEndpointOut
- Defined in:
- lib/svix/models/ingest_endpoint_out.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#disabled ⇒ Object
Returns the value of attribute disabled.
-
#id ⇒ Object
The Endpoint's ID.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#throttle_rate ⇒ Object
Maximum messages per second to send to this endpoint.
-
#uid ⇒ Object
Optional unique identifier for the endpoint.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ IngestEndpointOut
constructor
A new instance of IngestEndpointOut.
- #serialize ⇒ Object
-
#to_json ⇒ Object
Serializes the object to a json string.
Constructor Details
#initialize(attributes = {}) ⇒ IngestEndpointOut
Returns a new instance of IngestEndpointOut.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 35 def initialize(attributes = {}) unless attributes.is_a?(Hash) fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::IngestEndpointOut` new method") end attributes.each do |k, v| unless ALL_FIELD.include?(k.to_s) fail(ArgumentError, "The field #{k} is not part of Svix::IngestEndpointOut") end instance_variable_set("@#{k}", v) instance_variable_set("@__#{k}_is_defined", true) end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
18 19 20 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 18 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
10 11 12 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 10 def description @description end |
#disabled ⇒ Object
Returns the value of attribute disabled.
17 18 19 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 17 def disabled @disabled end |
#id ⇒ Object
The Endpoint's ID.
8 9 10 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 8 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
20 21 22 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 20 def @metadata end |
#throttle_rate ⇒ Object
Maximum messages per second to send to this endpoint.
Outgoing messages will be throttled to this rate.
14 15 16 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 14 def throttle_rate @throttle_rate end |
#uid ⇒ Object
Optional unique identifier for the endpoint.
16 17 18 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 16 def uid @uid end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
19 20 21 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 19 def updated_at @updated_at end |
#url ⇒ Object
Returns the value of attribute url.
9 10 11 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 9 def url @url end |
Class Method Details
.deserialize(attributes = {}) ⇒ Object
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 50 def self.deserialize(attributes = {}) attributes = attributes.transform_keys(&:to_s) attrs = Hash.new attrs["id"] = attributes["id"] attrs["url"] = attributes["url"] attrs["description"] = attributes["description"] attrs["throttle_rate"] = attributes["throttleRate"] attrs["uid"] = attributes["uid"] attrs["disabled"] = attributes["disabled"] attrs["created_at"] = DateTime.rfc3339(attributes["createdAt"]).to_time attrs["updated_at"] = DateTime.rfc3339(attributes["updatedAt"]).to_time attrs["metadata"] = attributes["metadata"] new(attrs) end |
Instance Method Details
#serialize ⇒ Object
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 65 def serialize out = Hash.new out["id"] = Svix::serialize_primitive(@id) if @id out["url"] = Svix::serialize_primitive(@url) if @url out["description"] = Svix::serialize_primitive(@description) if @description out["throttleRate"] = Svix::serialize_primitive(@throttle_rate) if @throttle_rate out["uid"] = Svix::serialize_primitive(@uid) if @uid out["disabled"] = Svix::serialize_primitive(@disabled) if @disabled out["createdAt"] = Svix::serialize_primitive(@created_at) if @created_at out["updatedAt"] = Svix::serialize_primitive(@updated_at) if @updated_at out["metadata"] = Svix::serialize_primitive(@metadata) if @metadata out end |
#to_json ⇒ Object
Serializes the object to a json string
81 82 83 |
# File 'lib/svix/models/ingest_endpoint_out.rb', line 81 def to_json JSON.dump(serialize) end |