Class: Svix::ApplicationIn
- Inherits:
-
Object
- Object
- Svix::ApplicationIn
- Defined in:
- lib/svix/models/application_in.rb
Instance Attribute Summary collapse
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Application name for human consumption.
-
#rate_limit ⇒ Object
Deprecated, use ‘throttleRate` instead.
-
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
-
#uid ⇒ Object
Optional unique identifier for the application.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ApplicationIn
constructor
A new instance of ApplicationIn.
- #serialize ⇒ Object
-
#to_json ⇒ Object
Serializes the object to a json string.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationIn
Returns a new instance of ApplicationIn.
22 23 24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/svix/models/application_in.rb', line 22 def initialize(attributes = {}) unless attributes.is_a?(Hash) fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::ApplicationIn` new method") end attributes.each do |k, v| unless ALL_FIELD.include?(k.to_s) fail(ArgumentError, "The field #{k} is not part of Svix::ApplicationIn") end instance_variable_set("@#{k}", v) instance_variable_set("@__#{k}_is_defined", true) end end |
Instance Attribute Details
#metadata ⇒ Object
Returns the value of attribute metadata.
7 8 9 |
# File 'lib/svix/models/application_in.rb', line 7 def @metadata end |
#name ⇒ Object
Application name for human consumption.
9 10 11 |
# File 'lib/svix/models/application_in.rb', line 9 def name @name end |
#rate_limit ⇒ Object
Deprecated, use ‘throttleRate` instead.
11 12 13 |
# File 'lib/svix/models/application_in.rb', line 11 def rate_limit @rate_limit end |
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
Outgoing messages will be throttled to this rate.
15 16 17 |
# File 'lib/svix/models/application_in.rb', line 15 def throttle_rate @throttle_rate end |
#uid ⇒ Object
Optional unique identifier for the application.
17 18 19 |
# File 'lib/svix/models/application_in.rb', line 17 def uid @uid end |
Class Method Details
.deserialize(attributes = {}) ⇒ Object
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/svix/models/application_in.rb', line 37 def self.deserialize(attributes = {}) attributes = attributes.transform_keys(&:to_s) attrs = Hash.new attrs["metadata"] = attributes["metadata"] attrs["name"] = attributes["name"] attrs["rate_limit"] = attributes["rateLimit"] attrs["throttle_rate"] = attributes["throttleRate"] attrs["uid"] = attributes["uid"] new(attrs) end |
Instance Method Details
#serialize ⇒ Object
48 49 50 51 52 53 54 55 56 |
# File 'lib/svix/models/application_in.rb', line 48 def serialize out = Hash.new out["metadata"] = Svix::serialize_primitive(@metadata) if @metadata out["name"] = Svix::serialize_primitive(@name) if @name out["rateLimit"] = Svix::serialize_primitive(@rate_limit) if @rate_limit out["throttleRate"] = Svix::serialize_primitive(@throttle_rate) if @throttle_rate out["uid"] = Svix::serialize_primitive(@uid) if @uid out end |
#to_json ⇒ Object
Serializes the object to a json string
60 61 62 |
# File 'lib/svix/models/application_in.rb', line 60 def to_json JSON.dump(serialize) end |