Class: Svix::ApplicationPatch
- Inherits:
-
Object
- Object
- Svix::ApplicationPatch
- Defined in:
- lib/svix/models/application_patch.rb
Instance Attribute Summary collapse
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#rate_limit ⇒ Object
Deprecated, use ‘throttleRate` instead.
-
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
-
#uid ⇒ Object
The Application’s UID.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attributes = {}) ⇒ ApplicationPatch
constructor
A new instance of ApplicationPatch.
- #serialize ⇒ Object
-
#to_json ⇒ Object
Serializes the object to a json string.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationPatch
Returns a new instance of ApplicationPatch.
21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/svix/models/application_patch.rb', line 21 def initialize(attributes = {}) unless attributes.is_a?(Hash) fail(ArgumentError, "The input argument (attributes) must be a hash in `Svix::ApplicationPatch` new method") end attributes.each do |k, v| unless ALL_FIELD.include?(k.to_s) fail(ArgumentError, "The field #{k} is not part of Svix::ApplicationPatch") end instance_variable_set("@#{k}", v) instance_variable_set("@__#{k}_is_defined", true) end end |
Instance Attribute Details
#metadata ⇒ Object
Returns the value of attribute metadata.
7 8 9 |
# File 'lib/svix/models/application_patch.rb', line 7 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
8 9 10 |
# File 'lib/svix/models/application_patch.rb', line 8 def name @name end |
#rate_limit ⇒ Object
Deprecated, use ‘throttleRate` instead.
10 11 12 |
# File 'lib/svix/models/application_patch.rb', line 10 def rate_limit @rate_limit end |
#throttle_rate ⇒ Object
Maximum messages per second to send to this application.
Outgoing messages will be throttled to this rate.
14 15 16 |
# File 'lib/svix/models/application_patch.rb', line 14 def throttle_rate @throttle_rate end |
#uid ⇒ Object
The Application’s UID.
16 17 18 |
# File 'lib/svix/models/application_patch.rb', line 16 def uid @uid end |
Class Method Details
.deserialize(attributes = {}) ⇒ Object
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/svix/models/application_patch.rb', line 36 def self.deserialize(attributes = {}) attributes = attributes.transform_keys(&:to_s) attrs = Hash.new attrs["metadata"] = attributes["metadata"] attrs["name"] = attributes["name"] attrs["rate_limit"] = attributes["rateLimit"] attrs["throttle_rate"] = attributes["throttleRate"] attrs["uid"] = attributes["uid"] new(attrs) end |
Instance Method Details
#serialize ⇒ Object
47 48 49 50 51 52 53 54 55 |
# File 'lib/svix/models/application_patch.rb', line 47 def serialize out = Hash.new out["metadata"] = Svix::serialize_primitive(@metadata) if @metadata out["name"] = Svix::serialize_primitive(@name) if @name out["rateLimit"] = Svix::serialize_primitive(@rate_limit) if @__rate_limit_is_defined out["throttleRate"] = Svix::serialize_primitive(@throttle_rate) if @__throttle_rate_is_defined out["uid"] = Svix::serialize_primitive(@uid) if @__uid_is_defined out end |
#to_json ⇒ Object
Serializes the object to a json string
59 60 61 |
# File 'lib/svix/models/application_patch.rb', line 59 def to_json JSON.dump(serialize) end |